================
 How-Tos
================


These How-Tos give more detailed information on how to use Zennit.

.. toctree::
    :maxdepth: 1

    use-rules-composites-and-canonizers
    use-attributors
    visualize-results
    get-intermediate-relevance
    compute-second-order-gradients
    write-custom-composites
    write-custom-canonizers
    write-custom-rules
    write-custom-attributors
